@@ -133,7 +133,7 @@ class DocDBClient:
 
     exceptions: Exceptions
 
-    def add_tags_to_resource(self, ResourceName: str, Tags: List[TagTypeDef]) -> None:
+    def add_tags_to_resource(self, ResourceName: str, Tags: List["TagTypeDef"]) -> None:
         """
         [Client.add_tags_to_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Client.add_tags_to_resource)
         """
@@ -155,7 +155,7 @@ class DocDBClient:
         SourceDBClusterParameterGroupIdentifier: str,
         TargetDBClusterParameterGroupIdentifier: str,
         TargetDBClusterParameterGroupDescription: str,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CopyDBClusterParameterGroupResultTypeDef:
         """
         [Client.copy_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Client.copy_db_cluster_parameter_group)
@@ -168,7 +168,7 @@ class DocDBClient:
         KmsKeyId: str = None,
         PreSignedUrl: str = None,
         CopyTags: bool = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CopyDBClusterSnapshotResultTypeDef:
         """
         [Client.copy_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Client.copy_db_cluster_snapshot)
@@ -189,7 +189,7 @@ class DocDBClient:
         Port: int = None,
         PreferredBackupWindow: str = None,
         PreferredMaintenanceWindow: str = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
         StorageEncrypted: bool = None,
         KmsKeyId: str = None,
         EnableCloudwatchLogsExports: List[str] = None,
@@ -204,7 +204,7 @@ class DocDBClient:
         DBClusterParameterGroupName: str,
         DBParameterGroupFamily: str,
         Description: str,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterParameterGroupResultTypeDef:
         """
         [Client.create_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Client.create_db_cluster_parameter_group)
@@ -214,7 +214,7 @@ class DocDBClient:
         self,
         DBClusterSnapshotIdentifier: str,
         DBClusterIdentifier: str,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateDBClusterSnapshotResultTypeDef:
         """
         [Client.create_db_cluster_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Client.create_db_cluster_snapshot)
@@ -229,7 +229,7 @@ class DocDBClient:
         AvailabilityZone: str = None,
         PreferredMaintenanceWindow: str = None,
         AutoMinorVersionUpgrade: bool = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
         PromotionTier: int = None,
     ) -> CreateDBInstanceResultTypeDef:
         """
@@ -241,7 +241,7 @@ class DocDBClient:
         DBSubnetGroupName: str,
         DBSubnetGroupDescription: str,
         SubnetIds: List[str],
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
     ) -> CreateDBSubnetGroupResultTypeDef:
         """
         [Client.create_db_subnet_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Client.create_db_subnet_group)
@@ -497,7 +497,7 @@ class DocDBClient:
         """
 
     def modify_db_cluster_parameter_group(
-        self, DBClusterParameterGroupName: str, Parameters: List[ParameterTypeDef]
+        self, DBClusterParameterGroupName: str, Parameters: List["ParameterTypeDef"]
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
         [Client.modify_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Client.modify_db_cluster_parameter_group)
@@ -552,7 +552,7 @@ class DocDBClient:
         self,
         DBClusterParameterGroupName: str,
         ResetAllParameters: bool = None,
-        Parameters: List[ParameterTypeDef] = None,
+        Parameters: List["ParameterTypeDef"] = None,
     ) -> DBClusterParameterGroupNameMessageTypeDef:
         """
         [Client.reset_db_cluster_parameter_group documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/docdb.html#DocDB.Client.reset_db_cluster_parameter_group)
@@ -568,7 +568,7 @@ class DocDBClient:
         Port: int = None,
         DBSubnetGroupName: str = None,
         VpcSecurityGroupIds: List[str] = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
         KmsKeyId: str = None,
         EnableCloudwatchLogsExports: List[str] = None,
         DeletionProtection: bool = None,
@@ -586,7 +586,7 @@ class DocDBClient:
         Port: int = None,
         DBSubnetGroupName: str = None,
         VpcSecurityGroupIds: List[str] = None,
-        Tags: List[TagTypeDef] = None,
+        Tags: List["TagTypeDef"] = None,
         KmsKeyId: str = None,
         EnableCloudwatchLogsExports: List[str] = None,
         DeletionProtection: bool = None,
