@@ -3,9 +3,9 @@ Main interface for docdb service type definitions.
 
 Usage::
 
-    from mypy_boto3.docdb.type_defs import PendingMaintenanceActionTypeDef
+    from mypy_boto3.docdb.type_defs import AvailabilityZoneTypeDef
 
-    data: PendingMaintenanceActionTypeDef = {...}
+    data: AvailabilityZoneTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,55 +22,57 @@ else:
 
 
 __all__ = (
-    "PendingMaintenanceActionTypeDef",
-    "ResourcePendingMaintenanceActionsTypeDef",
-    "ApplyPendingMaintenanceActionResultTypeDef",
-    "CertificateTypeDef",
-    "CertificateMessageTypeDef",
-    "CloudwatchLogsExportConfigurationTypeDef",
-    "DBClusterParameterGroupTypeDef",
-    "CopyDBClusterParameterGroupResultTypeDef",
-    "DBClusterSnapshotTypeDef",
-    "CopyDBClusterSnapshotResultTypeDef",
-    "CreateDBClusterParameterGroupResultTypeDef",
-    "DBClusterMemberTypeDef",
-    "DBClusterRoleTypeDef",
-    "VpcSecurityGroupMembershipTypeDef",
-    "DBClusterTypeDef",
-    "CreateDBClusterResultTypeDef",
-    "CreateDBClusterSnapshotResultTypeDef",
-    "DBInstanceStatusInfoTypeDef",
     "AvailabilityZoneTypeDef",
-    "SubnetTypeDef",
+    "CertificateTypeDef",
+    "DBClusterMemberTypeDef",
+    "DBClusterParameterGroupTypeDef",
+    "DBClusterRoleTypeDef",
+    "DBClusterSnapshotAttributeTypeDef",
+    "DBClusterSnapshotAttributesResultTypeDef",
+    "DBClusterSnapshotTypeDef",
+    "DBClusterTypeDef",
+    "DBEngineVersionTypeDef",
+    "DBInstanceStatusInfoTypeDef",
+    "DBInstanceTypeDef",
     "DBSubnetGroupTypeDef",
     "EndpointTypeDef",
+    "EngineDefaultsTypeDef",
+    "EventCategoriesMapTypeDef",
+    "EventTypeDef",
+    "OrderableDBInstanceOptionTypeDef",
+    "ParameterTypeDef",
     "PendingCloudwatchLogsExportsTypeDef",
+    "PendingMaintenanceActionTypeDef",
     "PendingModifiedValuesTypeDef",
-    "DBInstanceTypeDef",
+    "ResourcePendingMaintenanceActionsTypeDef",
+    "SubnetTypeDef",
+    "TagTypeDef",
+    "UpgradeTargetTypeDef",
+    "VpcSecurityGroupMembershipTypeDef",
+    "ApplyPendingMaintenanceActionResultTypeDef",
+    "CertificateMessageTypeDef",
+    "CloudwatchLogsExportConfigurationTypeDef",
+    "CopyDBClusterParameterGroupResultTypeDef",
+    "CopyDBClusterSnapshotResultTypeDef",
+    "CreateDBClusterParameterGroupResultTypeDef",
+    "CreateDBClusterResultTypeDef",
+    "CreateDBClusterSnapshotResultTypeDef",
     "CreateDBInstanceResultTypeDef",
     "CreateDBSubnetGroupResultTypeDef",
     "DBClusterMessageTypeDef",
-    "ParameterTypeDef",
     "DBClusterParameterGroupDetailsTypeDef",
     "DBClusterParameterGroupNameMessageTypeDef",
     "DBClusterParameterGroupsMessageTypeDef",
     "DBClusterSnapshotMessageTypeDef",
-    "UpgradeTargetTypeDef",
-    "DBEngineVersionTypeDef",
     "DBEngineVersionMessageTypeDef",
     "DBInstanceMessageTypeDef",
     "DBSubnetGroupMessageTypeDef",
     "DeleteDBClusterResultTypeDef",
     "DeleteDBClusterSnapshotResultTypeDef",
     "DeleteDBInstanceResultTypeDef",
-    "DBClusterSnapshotAttributeTypeDef",
-    "DBClusterSnapshotAttributesResultTypeDef",
     "DescribeDBClusterSnapshotAttributesResultTypeDef",
-    "EngineDefaultsTypeDef",
     "DescribeEngineDefaultClusterParametersResultTypeDef",
-    "EventCategoriesMapTypeDef",
     "EventCategoriesMessageTypeDef",
-    "EventTypeDef",
     "EventsMessageTypeDef",
     "FailoverDBClusterResultTypeDef",
     "FilterTypeDef",
@@ -78,7 +80,6 @@ __all__ = (
     "ModifyDBClusterSnapshotAttributeResultTypeDef",
     "ModifyDBInstanceResultTypeDef",
     "ModifyDBSubnetGroupResultTypeDef",
-    "OrderableDBInstanceOptionTypeDef",
     "OrderableDBInstanceOptionsMessageTypeDef",
     "PaginatorConfigTypeDef",
     "PendingMaintenanceActionsMessageTypeDef",
@@ -87,38 +88,11 @@ __all__ = (
     "RestoreDBClusterToPointInTimeResultTypeDef",
     "StartDBClusterResultTypeDef",
     "StopDBClusterResultTypeDef",
-    "TagTypeDef",
     "TagListMessageTypeDef",
     "WaiterConfigTypeDef",
 )
 
-PendingMaintenanceActionTypeDef = TypedDict(
-    "PendingMaintenanceActionTypeDef",
-    {
-        "Action": str,
-        "AutoAppliedAfterDate": datetime,
-        "ForcedApplyDate": datetime,
-        "OptInStatus": str,
-        "CurrentApplyDate": datetime,
-        "Description": str,
-    },
-    total=False,
-)
-
-ResourcePendingMaintenanceActionsTypeDef = TypedDict(
-    "ResourcePendingMaintenanceActionsTypeDef",
-    {
-        "ResourceIdentifier": str,
-        "PendingMaintenanceActionDetails": List[PendingMaintenanceActionTypeDef],
-    },
-    total=False,
-)
-
-ApplyPendingMaintenanceActionResultTypeDef = TypedDict(
-    "ApplyPendingMaintenanceActionResultTypeDef",
-    {"ResourcePendingMaintenanceActions": ResourcePendingMaintenanceActionsTypeDef},
-    total=False,
-)
+AvailabilityZoneTypeDef = TypedDict("AvailabilityZoneTypeDef", {"Name": str}, total=False)
 
 CertificateTypeDef = TypedDict(
     "CertificateTypeDef",
@@ -133,15 +107,14 @@ CertificateTypeDef = TypedDict(
     total=False,
 )
 
-CertificateMessageTypeDef = TypedDict(
-    "CertificateMessageTypeDef",
-    {"Certificates": List[CertificateTypeDef], "Marker": str},
-    total=False,
-)
-
-CloudwatchLogsExportConfigurationTypeDef = TypedDict(
-    "CloudwatchLogsExportConfigurationTypeDef",
-    {"EnableLogTypes": List[str], "DisableLogTypes": List[str]},
+DBClusterMemberTypeDef = TypedDict(
+    "DBClusterMemberTypeDef",
+    {
+        "DBInstanceIdentifier": str,
+        "IsClusterWriter": bool,
+        "DBClusterParameterGroupStatus": str,
+        "PromotionTier": int,
+    },
     total=False,
 )
 
@@ -156,9 +129,22 @@ DBClusterParameterGroupTypeDef = TypedDict(
     total=False,
 )
 
-CopyDBClusterParameterGroupResultTypeDef = TypedDict(
-    "CopyDBClusterParameterGroupResultTypeDef",
-    {"DBClusterParameterGroup": DBClusterParameterGroupTypeDef},
+DBClusterRoleTypeDef = TypedDict(
+    "DBClusterRoleTypeDef", {"RoleArn": str, "Status": str}, total=False
+)
+
+DBClusterSnapshotAttributeTypeDef = TypedDict(
+    "DBClusterSnapshotAttributeTypeDef",
+    {"AttributeName": str, "AttributeValues": List[str]},
+    total=False,
+)
+
+DBClusterSnapshotAttributesResultTypeDef = TypedDict(
+    "DBClusterSnapshotAttributesResultTypeDef",
+    {
+        "DBClusterSnapshotIdentifier": str,
+        "DBClusterSnapshotAttributes": List["DBClusterSnapshotAttributeTypeDef"],
+    },
     total=False,
 )
 
@@ -186,37 +172,6 @@ DBClusterSnapshotTypeDef = TypedDict(
     total=False,
 )
 
-CopyDBClusterSnapshotResultTypeDef = TypedDict(
-    "CopyDBClusterSnapshotResultTypeDef",
-    {"DBClusterSnapshot": DBClusterSnapshotTypeDef},
-    total=False,
-)
-
-CreateDBClusterParameterGroupResultTypeDef = TypedDict(
-    "CreateDBClusterParameterGroupResultTypeDef",
-    {"DBClusterParameterGroup": DBClusterParameterGroupTypeDef},
-    total=False,
-)
-
-DBClusterMemberTypeDef = TypedDict(
-    "DBClusterMemberTypeDef",
-    {
-        "DBInstanceIdentifier": str,
-        "IsClusterWriter": bool,
-        "DBClusterParameterGroupStatus": str,
-        "PromotionTier": int,
-    },
-    total=False,
-)
-
-DBClusterRoleTypeDef = TypedDict(
-    "DBClusterRoleTypeDef", {"RoleArn": str, "Status": str}, total=False
-)
-
-VpcSecurityGroupMembershipTypeDef = TypedDict(
-    "VpcSecurityGroupMembershipTypeDef", {"VpcSecurityGroupId": str, "Status": str}, total=False
-)
-
 DBClusterTypeDef = TypedDict(
     "DBClusterTypeDef",
     {
@@ -238,14 +193,14 @@ DBClusterTypeDef = TypedDict(
         "MasterUsername": str,
         "PreferredBackupWindow": str,
         "PreferredMaintenanceWindow": str,
-        "DBClusterMembers": List[DBClusterMemberTypeDef],
-        "VpcSecurityGroups": List[VpcSecurityGroupMembershipTypeDef],
+        "DBClusterMembers": List["DBClusterMemberTypeDef"],
+        "VpcSecurityGroups": List["VpcSecurityGroupMembershipTypeDef"],
         "HostedZoneId": str,
         "StorageEncrypted": bool,
         "KmsKeyId": str,
         "DbClusterResourceId": str,
         "DBClusterArn": str,
-        "AssociatedRoles": List[DBClusterRoleTypeDef],
+        "AssociatedRoles": List["DBClusterRoleTypeDef"],
         "ClusterCreateTime": datetime,
         "EnabledCloudwatchLogsExports": List[str],
         "DeletionProtection": bool,
@@ -253,174 +208,6 @@ DBClusterTypeDef = TypedDict(
     total=False,
 )
 
-CreateDBClusterResultTypeDef = TypedDict(
-    "CreateDBClusterResultTypeDef", {"DBCluster": DBClusterTypeDef}, total=False
-)
-
-CreateDBClusterSnapshotResultTypeDef = TypedDict(
-    "CreateDBClusterSnapshotResultTypeDef",
-    {"DBClusterSnapshot": DBClusterSnapshotTypeDef},
-    total=False,
-)
-
-DBInstanceStatusInfoTypeDef = TypedDict(
-    "DBInstanceStatusInfoTypeDef",
-    {"StatusType": str, "Normal": bool, "Status": str, "Message": str},
-    total=False,
-)
-
-AvailabilityZoneTypeDef = TypedDict("AvailabilityZoneTypeDef", {"Name": str}, total=False)
-
-SubnetTypeDef = TypedDict(
-    "SubnetTypeDef",
-    {
-        "SubnetIdentifier": str,
-        "SubnetAvailabilityZone": AvailabilityZoneTypeDef,
-        "SubnetStatus": str,
-    },
-    total=False,
-)
-
-DBSubnetGroupTypeDef = TypedDict(
-    "DBSubnetGroupTypeDef",
-    {
-        "DBSubnetGroupName": str,
-        "DBSubnetGroupDescription": str,
-        "VpcId": str,
-        "SubnetGroupStatus": str,
-        "Subnets": List[SubnetTypeDef],
-        "DBSubnetGroupArn": str,
-    },
-    total=False,
-)
-
-EndpointTypeDef = TypedDict(
-    "EndpointTypeDef", {"Address": str, "Port": int, "HostedZoneId": str}, total=False
-)
-
-PendingCloudwatchLogsExportsTypeDef = TypedDict(
-    "PendingCloudwatchLogsExportsTypeDef",
-    {"LogTypesToEnable": List[str], "LogTypesToDisable": List[str]},
-    total=False,
-)
-
-PendingModifiedValuesTypeDef = TypedDict(
-    "PendingModifiedValuesTypeDef",
-    {
-        "DBInstanceClass": str,
-        "AllocatedStorage": int,
-        "MasterUserPassword": str,
-        "Port": int,
-        "BackupRetentionPeriod": int,
-        "MultiAZ": bool,
-        "EngineVersion": str,
-        "LicenseModel": str,
-        "Iops": int,
-        "DBInstanceIdentifier": str,
-        "StorageType": str,
-        "CACertificateIdentifier": str,
-        "DBSubnetGroupName": str,
-        "PendingCloudwatchLogsExports": PendingCloudwatchLogsExportsTypeDef,
-    },
-    total=False,
-)
-
-DBInstanceTypeDef = TypedDict(
-    "DBInstanceTypeDef",
-    {
-        "DBInstanceIdentifier": str,
-        "DBInstanceClass": str,
-        "Engine": str,
-        "DBInstanceStatus": str,
-        "Endpoint": EndpointTypeDef,
-        "InstanceCreateTime": datetime,
-        "PreferredBackupWindow": str,
-        "BackupRetentionPeriod": int,
-        "VpcSecurityGroups": List[VpcSecurityGroupMembershipTypeDef],
-        "AvailabilityZone": str,
-        "DBSubnetGroup": DBSubnetGroupTypeDef,
-        "PreferredMaintenanceWindow": str,
-        "PendingModifiedValues": PendingModifiedValuesTypeDef,
-        "LatestRestorableTime": datetime,
-        "EngineVersion": str,
-        "AutoMinorVersionUpgrade": bool,
-        "PubliclyAccessible": bool,
-        "StatusInfos": List[DBInstanceStatusInfoTypeDef],
-        "DBClusterIdentifier": str,
-        "StorageEncrypted": bool,
-        "KmsKeyId": str,
-        "DbiResourceId": str,
-        "CACertificateIdentifier": str,
-        "PromotionTier": int,
-        "DBInstanceArn": str,
-        "EnabledCloudwatchLogsExports": List[str],
-    },
-    total=False,
-)
-
-CreateDBInstanceResultTypeDef = TypedDict(
-    "CreateDBInstanceResultTypeDef", {"DBInstance": DBInstanceTypeDef}, total=False
-)
-
-CreateDBSubnetGroupResultTypeDef = TypedDict(
-    "CreateDBSubnetGroupResultTypeDef", {"DBSubnetGroup": DBSubnetGroupTypeDef}, total=False
-)
-
-DBClusterMessageTypeDef = TypedDict(
-    "DBClusterMessageTypeDef", {"Marker": str, "DBClusters": List[DBClusterTypeDef]}, total=False
-)
-
-ParameterTypeDef = TypedDict(
-    "ParameterTypeDef",
-    {
-        "ParameterName": str,
-        "ParameterValue": str,
-        "Description": str,
-        "Source": str,
-        "ApplyType": str,
-        "DataType": str,
-        "AllowedValues": str,
-        "IsModifiable": bool,
-        "MinimumEngineVersion": str,
-        "ApplyMethod": Literal["immediate", "pending-reboot"],
-    },
-    total=False,
-)
-
-DBClusterParameterGroupDetailsTypeDef = TypedDict(
-    "DBClusterParameterGroupDetailsTypeDef",
-    {"Parameters": List[ParameterTypeDef], "Marker": str},
-    total=False,
-)
-
-DBClusterParameterGroupNameMessageTypeDef = TypedDict(
-    "DBClusterParameterGroupNameMessageTypeDef", {"DBClusterParameterGroupName": str}, total=False
-)
-
-DBClusterParameterGroupsMessageTypeDef = TypedDict(
-    "DBClusterParameterGroupsMessageTypeDef",
-    {"Marker": str, "DBClusterParameterGroups": List[DBClusterParameterGroupTypeDef]},
-    total=False,
-)
-
-DBClusterSnapshotMessageTypeDef = TypedDict(
-    "DBClusterSnapshotMessageTypeDef",
-    {"Marker": str, "DBClusterSnapshots": List[DBClusterSnapshotTypeDef]},
-    total=False,
-)
-
-UpgradeTargetTypeDef = TypedDict(
-    "UpgradeTargetTypeDef",
-    {
-        "Engine": str,
-        "EngineVersion": str,
-        "Description": str,
-        "AutoUpgrade": bool,
-        "IsMajorVersionUpgrade": bool,
-    },
-    total=False,
-)
-
 DBEngineVersionTypeDef = TypedDict(
     "DBEngineVersionTypeDef",
     {
@@ -429,73 +216,72 @@ DBEngineVersionTypeDef = TypedDict(
         "DBParameterGroupFamily": str,
         "DBEngineDescription": str,
         "DBEngineVersionDescription": str,
-        "ValidUpgradeTarget": List[UpgradeTargetTypeDef],
+        "ValidUpgradeTarget": List["UpgradeTargetTypeDef"],
         "ExportableLogTypes": List[str],
         "SupportsLogExportsToCloudwatchLogs": bool,
     },
     total=False,
 )
 
-DBEngineVersionMessageTypeDef = TypedDict(
-    "DBEngineVersionMessageTypeDef",
-    {"Marker": str, "DBEngineVersions": List[DBEngineVersionTypeDef]},
+DBInstanceStatusInfoTypeDef = TypedDict(
+    "DBInstanceStatusInfoTypeDef",
+    {"StatusType": str, "Normal": bool, "Status": str, "Message": str},
     total=False,
 )
 
-DBInstanceMessageTypeDef = TypedDict(
-    "DBInstanceMessageTypeDef", {"Marker": str, "DBInstances": List[DBInstanceTypeDef]}, total=False
-)
-
-DBSubnetGroupMessageTypeDef = TypedDict(
-    "DBSubnetGroupMessageTypeDef",
-    {"Marker": str, "DBSubnetGroups": List[DBSubnetGroupTypeDef]},
-    total=False,
-)
-
-DeleteDBClusterResultTypeDef = TypedDict(
-    "DeleteDBClusterResultTypeDef", {"DBCluster": DBClusterTypeDef}, total=False
-)
-
-DeleteDBClusterSnapshotResultTypeDef = TypedDict(
-    "DeleteDBClusterSnapshotResultTypeDef",
-    {"DBClusterSnapshot": DBClusterSnapshotTypeDef},
-    total=False,
-)
-
-DeleteDBInstanceResultTypeDef = TypedDict(
-    "DeleteDBInstanceResultTypeDef", {"DBInstance": DBInstanceTypeDef}, total=False
-)
-
-DBClusterSnapshotAttributeTypeDef = TypedDict(
-    "DBClusterSnapshotAttributeTypeDef",
-    {"AttributeName": str, "AttributeValues": List[str]},
-    total=False,
-)
-
-DBClusterSnapshotAttributesResultTypeDef = TypedDict(
-    "DBClusterSnapshotAttributesResultTypeDef",
+DBInstanceTypeDef = TypedDict(
+    "DBInstanceTypeDef",
     {
-        "DBClusterSnapshotIdentifier": str,
-        "DBClusterSnapshotAttributes": List[DBClusterSnapshotAttributeTypeDef],
+        "DBInstanceIdentifier": str,
+        "DBInstanceClass": str,
+        "Engine": str,
+        "DBInstanceStatus": str,
+        "Endpoint": "EndpointTypeDef",
+        "InstanceCreateTime": datetime,
+        "PreferredBackupWindow": str,
+        "BackupRetentionPeriod": int,
+        "VpcSecurityGroups": List["VpcSecurityGroupMembershipTypeDef"],
+        "AvailabilityZone": str,
+        "DBSubnetGroup": "DBSubnetGroupTypeDef",
+        "PreferredMaintenanceWindow": str,
+        "PendingModifiedValues": "PendingModifiedValuesTypeDef",
+        "LatestRestorableTime": datetime,
+        "EngineVersion": str,
+        "AutoMinorVersionUpgrade": bool,
+        "PubliclyAccessible": bool,
+        "StatusInfos": List["DBInstanceStatusInfoTypeDef"],
+        "DBClusterIdentifier": str,
+        "StorageEncrypted": bool,
+        "KmsKeyId": str,
+        "DbiResourceId": str,
+        "CACertificateIdentifier": str,
+        "PromotionTier": int,
+        "DBInstanceArn": str,
+        "EnabledCloudwatchLogsExports": List[str],
     },
     total=False,
 )
 
-DescribeDBClusterSnapshotAttributesResultTypeDef = TypedDict(
-    "DescribeDBClusterSnapshotAttributesResultTypeDef",
-    {"DBClusterSnapshotAttributesResult": DBClusterSnapshotAttributesResultTypeDef},
+DBSubnetGroupTypeDef = TypedDict(
+    "DBSubnetGroupTypeDef",
+    {
+        "DBSubnetGroupName": str,
+        "DBSubnetGroupDescription": str,
+        "VpcId": str,
+        "SubnetGroupStatus": str,
+        "Subnets": List["SubnetTypeDef"],
+        "DBSubnetGroupArn": str,
+    },
     total=False,
 )
 
+EndpointTypeDef = TypedDict(
+    "EndpointTypeDef", {"Address": str, "Port": int, "HostedZoneId": str}, total=False
+)
+
 EngineDefaultsTypeDef = TypedDict(
     "EngineDefaultsTypeDef",
-    {"DBParameterGroupFamily": str, "Marker": str, "Parameters": List[ParameterTypeDef]},
-    total=False,
-)
-
-DescribeEngineDefaultClusterParametersResultTypeDef = TypedDict(
-    "DescribeEngineDefaultClusterParametersResultTypeDef",
-    {"EngineDefaults": EngineDefaultsTypeDef},
+    {"DBParameterGroupFamily": str, "Marker": str, "Parameters": List["ParameterTypeDef"]},
     total=False,
 )
 
@@ -503,12 +289,6 @@ EventCategoriesMapTypeDef = TypedDict(
     "EventCategoriesMapTypeDef", {"SourceType": str, "EventCategories": List[str]}, total=False
 )
 
-EventCategoriesMessageTypeDef = TypedDict(
-    "EventCategoriesMessageTypeDef",
-    {"EventCategoriesMapList": List[EventCategoriesMapTypeDef]},
-    total=False,
-)
-
 EventTypeDef = TypedDict(
     "EventTypeDef",
     {
@@ -529,34 +309,6 @@ EventTypeDef = TypedDict(
     total=False,
 )
 
-EventsMessageTypeDef = TypedDict(
-    "EventsMessageTypeDef", {"Marker": str, "Events": List[EventTypeDef]}, total=False
-)
-
-FailoverDBClusterResultTypeDef = TypedDict(
-    "FailoverDBClusterResultTypeDef", {"DBCluster": DBClusterTypeDef}, total=False
-)
-
-FilterTypeDef = TypedDict("FilterTypeDef", {"Name": str, "Values": List[str]})
-
-ModifyDBClusterResultTypeDef = TypedDict(
-    "ModifyDBClusterResultTypeDef", {"DBCluster": DBClusterTypeDef}, total=False
-)
-
-ModifyDBClusterSnapshotAttributeResultTypeDef = TypedDict(
-    "ModifyDBClusterSnapshotAttributeResultTypeDef",
-    {"DBClusterSnapshotAttributesResult": DBClusterSnapshotAttributesResultTypeDef},
-    total=False,
-)
-
-ModifyDBInstanceResultTypeDef = TypedDict(
-    "ModifyDBInstanceResultTypeDef", {"DBInstance": DBInstanceTypeDef}, total=False
-)
-
-ModifyDBSubnetGroupResultTypeDef = TypedDict(
-    "ModifyDBSubnetGroupResultTypeDef", {"DBSubnetGroup": DBSubnetGroupTypeDef}, total=False
-)
-
 OrderableDBInstanceOptionTypeDef = TypedDict(
     "OrderableDBInstanceOptionTypeDef",
     {
@@ -564,15 +316,267 @@ OrderableDBInstanceOptionTypeDef = TypedDict(
         "EngineVersion": str,
         "DBInstanceClass": str,
         "LicenseModel": str,
-        "AvailabilityZones": List[AvailabilityZoneTypeDef],
+        "AvailabilityZones": List["AvailabilityZoneTypeDef"],
         "Vpc": bool,
     },
     total=False,
 )
 
+ParameterTypeDef = TypedDict(
+    "ParameterTypeDef",
+    {
+        "ParameterName": str,
+        "ParameterValue": str,
+        "Description": str,
+        "Source": str,
+        "ApplyType": str,
+        "DataType": str,
+        "AllowedValues": str,
+        "IsModifiable": bool,
+        "MinimumEngineVersion": str,
+        "ApplyMethod": Literal["immediate", "pending-reboot"],
+    },
+    total=False,
+)
+
+PendingCloudwatchLogsExportsTypeDef = TypedDict(
+    "PendingCloudwatchLogsExportsTypeDef",
+    {"LogTypesToEnable": List[str], "LogTypesToDisable": List[str]},
+    total=False,
+)
+
+PendingMaintenanceActionTypeDef = TypedDict(
+    "PendingMaintenanceActionTypeDef",
+    {
+        "Action": str,
+        "AutoAppliedAfterDate": datetime,
+        "ForcedApplyDate": datetime,
+        "OptInStatus": str,
+        "CurrentApplyDate": datetime,
+        "Description": str,
+    },
+    total=False,
+)
+
+PendingModifiedValuesTypeDef = TypedDict(
+    "PendingModifiedValuesTypeDef",
+    {
+        "DBInstanceClass": str,
+        "AllocatedStorage": int,
+        "MasterUserPassword": str,
+        "Port": int,
+        "BackupRetentionPeriod": int,
+        "MultiAZ": bool,
+        "EngineVersion": str,
+        "LicenseModel": str,
+        "Iops": int,
+        "DBInstanceIdentifier": str,
+        "StorageType": str,
+        "CACertificateIdentifier": str,
+        "DBSubnetGroupName": str,
+        "PendingCloudwatchLogsExports": "PendingCloudwatchLogsExportsTypeDef",
+    },
+    total=False,
+)
+
+ResourcePendingMaintenanceActionsTypeDef = TypedDict(
+    "ResourcePendingMaintenanceActionsTypeDef",
+    {
+        "ResourceIdentifier": str,
+        "PendingMaintenanceActionDetails": List["PendingMaintenanceActionTypeDef"],
+    },
+    total=False,
+)
+
+SubnetTypeDef = TypedDict(
+    "SubnetTypeDef",
+    {
+        "SubnetIdentifier": str,
+        "SubnetAvailabilityZone": "AvailabilityZoneTypeDef",
+        "SubnetStatus": str,
+    },
+    total=False,
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
+
+UpgradeTargetTypeDef = TypedDict(
+    "UpgradeTargetTypeDef",
+    {
+        "Engine": str,
+        "EngineVersion": str,
+        "Description": str,
+        "AutoUpgrade": bool,
+        "IsMajorVersionUpgrade": bool,
+    },
+    total=False,
+)
+
+VpcSecurityGroupMembershipTypeDef = TypedDict(
+    "VpcSecurityGroupMembershipTypeDef", {"VpcSecurityGroupId": str, "Status": str}, total=False
+)
+
+ApplyPendingMaintenanceActionResultTypeDef = TypedDict(
+    "ApplyPendingMaintenanceActionResultTypeDef",
+    {"ResourcePendingMaintenanceActions": "ResourcePendingMaintenanceActionsTypeDef"},
+    total=False,
+)
+
+CertificateMessageTypeDef = TypedDict(
+    "CertificateMessageTypeDef",
+    {"Certificates": List["CertificateTypeDef"], "Marker": str},
+    total=False,
+)
+
+CloudwatchLogsExportConfigurationTypeDef = TypedDict(
+    "CloudwatchLogsExportConfigurationTypeDef",
+    {"EnableLogTypes": List[str], "DisableLogTypes": List[str]},
+    total=False,
+)
+
+CopyDBClusterParameterGroupResultTypeDef = TypedDict(
+    "CopyDBClusterParameterGroupResultTypeDef",
+    {"DBClusterParameterGroup": "DBClusterParameterGroupTypeDef"},
+    total=False,
+)
+
+CopyDBClusterSnapshotResultTypeDef = TypedDict(
+    "CopyDBClusterSnapshotResultTypeDef",
+    {"DBClusterSnapshot": "DBClusterSnapshotTypeDef"},
+    total=False,
+)
+
+CreateDBClusterParameterGroupResultTypeDef = TypedDict(
+    "CreateDBClusterParameterGroupResultTypeDef",
+    {"DBClusterParameterGroup": "DBClusterParameterGroupTypeDef"},
+    total=False,
+)
+
+CreateDBClusterResultTypeDef = TypedDict(
+    "CreateDBClusterResultTypeDef", {"DBCluster": "DBClusterTypeDef"}, total=False
+)
+
+CreateDBClusterSnapshotResultTypeDef = TypedDict(
+    "CreateDBClusterSnapshotResultTypeDef",
+    {"DBClusterSnapshot": "DBClusterSnapshotTypeDef"},
+    total=False,
+)
+
+CreateDBInstanceResultTypeDef = TypedDict(
+    "CreateDBInstanceResultTypeDef", {"DBInstance": "DBInstanceTypeDef"}, total=False
+)
+
+CreateDBSubnetGroupResultTypeDef = TypedDict(
+    "CreateDBSubnetGroupResultTypeDef", {"DBSubnetGroup": "DBSubnetGroupTypeDef"}, total=False
+)
+
+DBClusterMessageTypeDef = TypedDict(
+    "DBClusterMessageTypeDef", {"Marker": str, "DBClusters": List["DBClusterTypeDef"]}, total=False
+)
+
+DBClusterParameterGroupDetailsTypeDef = TypedDict(
+    "DBClusterParameterGroupDetailsTypeDef",
+    {"Parameters": List["ParameterTypeDef"], "Marker": str},
+    total=False,
+)
+
+DBClusterParameterGroupNameMessageTypeDef = TypedDict(
+    "DBClusterParameterGroupNameMessageTypeDef", {"DBClusterParameterGroupName": str}, total=False
+)
+
+DBClusterParameterGroupsMessageTypeDef = TypedDict(
+    "DBClusterParameterGroupsMessageTypeDef",
+    {"Marker": str, "DBClusterParameterGroups": List["DBClusterParameterGroupTypeDef"]},
+    total=False,
+)
+
+DBClusterSnapshotMessageTypeDef = TypedDict(
+    "DBClusterSnapshotMessageTypeDef",
+    {"Marker": str, "DBClusterSnapshots": List["DBClusterSnapshotTypeDef"]},
+    total=False,
+)
+
+DBEngineVersionMessageTypeDef = TypedDict(
+    "DBEngineVersionMessageTypeDef",
+    {"Marker": str, "DBEngineVersions": List["DBEngineVersionTypeDef"]},
+    total=False,
+)
+
+DBInstanceMessageTypeDef = TypedDict(
+    "DBInstanceMessageTypeDef",
+    {"Marker": str, "DBInstances": List["DBInstanceTypeDef"]},
+    total=False,
+)
+
+DBSubnetGroupMessageTypeDef = TypedDict(
+    "DBSubnetGroupMessageTypeDef",
+    {"Marker": str, "DBSubnetGroups": List["DBSubnetGroupTypeDef"]},
+    total=False,
+)
+
+DeleteDBClusterResultTypeDef = TypedDict(
+    "DeleteDBClusterResultTypeDef", {"DBCluster": "DBClusterTypeDef"}, total=False
+)
+
+DeleteDBClusterSnapshotResultTypeDef = TypedDict(
+    "DeleteDBClusterSnapshotResultTypeDef",
+    {"DBClusterSnapshot": "DBClusterSnapshotTypeDef"},
+    total=False,
+)
+
+DeleteDBInstanceResultTypeDef = TypedDict(
+    "DeleteDBInstanceResultTypeDef", {"DBInstance": "DBInstanceTypeDef"}, total=False
+)
+
+DescribeDBClusterSnapshotAttributesResultTypeDef = TypedDict(
+    "DescribeDBClusterSnapshotAttributesResultTypeDef",
+    {"DBClusterSnapshotAttributesResult": "DBClusterSnapshotAttributesResultTypeDef"},
+    total=False,
+)
+
+DescribeEngineDefaultClusterParametersResultTypeDef = TypedDict(
+    "DescribeEngineDefaultClusterParametersResultTypeDef",
+    {"EngineDefaults": "EngineDefaultsTypeDef"},
+    total=False,
+)
+
+EventCategoriesMessageTypeDef = TypedDict(
+    "EventCategoriesMessageTypeDef",
+    {"EventCategoriesMapList": List["EventCategoriesMapTypeDef"]},
+    total=False,
+)
+
+EventsMessageTypeDef = TypedDict(
+    "EventsMessageTypeDef", {"Marker": str, "Events": List["EventTypeDef"]}, total=False
+)
+
+FailoverDBClusterResultTypeDef = TypedDict(
+    "FailoverDBClusterResultTypeDef", {"DBCluster": "DBClusterTypeDef"}, total=False
+)
+
+FilterTypeDef = TypedDict("FilterTypeDef", {"Name": str, "Values": List[str]})
+
+ModifyDBClusterResultTypeDef = TypedDict(
+    "ModifyDBClusterResultTypeDef", {"DBCluster": "DBClusterTypeDef"}, total=False
+)
+
+ModifyDBClusterSnapshotAttributeResultTypeDef = TypedDict(
+    "ModifyDBClusterSnapshotAttributeResultTypeDef",
+    {"DBClusterSnapshotAttributesResult": "DBClusterSnapshotAttributesResultTypeDef"},
+    total=False,
+)
+
+ModifyDBInstanceResultTypeDef = TypedDict(
+    "ModifyDBInstanceResultTypeDef", {"DBInstance": "DBInstanceTypeDef"}, total=False
+)
+
+ModifyDBSubnetGroupResultTypeDef = TypedDict(
+    "ModifyDBSubnetGroupResultTypeDef", {"DBSubnetGroup": "DBSubnetGroupTypeDef"}, total=False
+)
+
 OrderableDBInstanceOptionsMessageTypeDef = TypedDict(
     "OrderableDBInstanceOptionsMessageTypeDef",
-    {"OrderableDBInstanceOptions": List[OrderableDBInstanceOptionTypeDef], "Marker": str},
+    {"OrderableDBInstanceOptions": List["OrderableDBInstanceOptionTypeDef"], "Marker": str},
     total=False,
 )
 
@@ -582,34 +586,32 @@ PaginatorConfigTypeDef = TypedDict(
 
 PendingMaintenanceActionsMessageTypeDef = TypedDict(
     "PendingMaintenanceActionsMessageTypeDef",
-    {"PendingMaintenanceActions": List[ResourcePendingMaintenanceActionsTypeDef], "Marker": str},
+    {"PendingMaintenanceActions": List["ResourcePendingMaintenanceActionsTypeDef"], "Marker": str},
     total=False,
 )
 
 RebootDBInstanceResultTypeDef = TypedDict(
-    "RebootDBInstanceResultTypeDef", {"DBInstance": DBInstanceTypeDef}, total=False
+    "RebootDBInstanceResultTypeDef", {"DBInstance": "DBInstanceTypeDef"}, total=False
 )
 
 RestoreDBClusterFromSnapshotResultTypeDef = TypedDict(
-    "RestoreDBClusterFromSnapshotResultTypeDef", {"DBCluster": DBClusterTypeDef}, total=False
+    "RestoreDBClusterFromSnapshotResultTypeDef", {"DBCluster": "DBClusterTypeDef"}, total=False
 )
 
 RestoreDBClusterToPointInTimeResultTypeDef = TypedDict(
-    "RestoreDBClusterToPointInTimeResultTypeDef", {"DBCluster": DBClusterTypeDef}, total=False
+    "RestoreDBClusterToPointInTimeResultTypeDef", {"DBCluster": "DBClusterTypeDef"}, total=False
 )
 
 StartDBClusterResultTypeDef = TypedDict(
-    "StartDBClusterResultTypeDef", {"DBCluster": DBClusterTypeDef}, total=False
+    "StartDBClusterResultTypeDef", {"DBCluster": "DBClusterTypeDef"}, total=False
 )
 
 StopDBClusterResultTypeDef = TypedDict(
-    "StopDBClusterResultTypeDef", {"DBCluster": DBClusterTypeDef}, total=False
+    "StopDBClusterResultTypeDef", {"DBCluster": "DBClusterTypeDef"}, total=False
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
-
 TagListMessageTypeDef = TypedDict(
-    "TagListMessageTypeDef", {"TagList": List[TagTypeDef]}, total=False
+    "TagListMessageTypeDef", {"TagList": List["TagTypeDef"]}, total=False
 )
 
 WaiterConfigTypeDef = TypedDict(
